@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -416,9 +416,6 @@ INVALIDPARAMETERVALUE_PARAMETERCHARACTERERROR = 'InvalidParameterValue.Parameter
 # 参数不满足规则，请修改后重试。
 INVALIDPARAMETERVALUE_PARAMETERCHARACTERLIMITERROR = 'InvalidParameterValue.ParameterCharacterLimitError'
 
-# 参数前缀设置不符合规则要求，请修改后重试。
-INVALIDPARAMETERVALUE_PARAMETERCHARACTERPRELIMITERROR = 'InvalidParameterValue.ParameterCharacterPreLimitError'
-
 # 参数处理失败，请检参数值设置是否有效。
 INVALIDPARAMETERVALUE_PARAMETERHANDLEERROR = 'InvalidParameterValue.ParameterHandleError'
 
@@ -482,6 +479,9 @@ OPERATIONDENIED_INSTANCESTATUSLIMITOPERROR = 'OperationDenied.InstanceStatusLimi
 # 实例类型错误
 OPERATIONDENIED_INSTANCETYPEDENIED = 'OperationDenied.InstanceTypeDenied'
 
+# 账号余额不足。
+OPERATIONDENIED_INSUFFICIENTBALANCEERROR = 'OperationDenied.InsufficientBalanceError'
+
 # 内核版本过低，导致实例无法创建tencentDBSuper账号。如果您想使用此功能，请升级内核版本。
 OPERATIONDENIED_KERNELVERSIONERROR = 'OperationDenied.KernelVersionError'
 
@@ -506,6 +506,9 @@ OPERATIONDENIED_ROINSTANCESTATUSLIMITOPERROR = 'OperationDenied.ROInstanceStatus
 # 只读节点总数不能超过上限值。
 OPERATIONDENIED_ROINSTANCECOUNTEXEEDERROR = 'OperationDenied.RoInstanceCountExeedError'
 
+# 无支付权限，开通失败。
+OPERATIONDENIED_TRADEPERMISSIONERROR = 'OperationDenied.TradePermissionError'
+
 # 用户未进行实名认证，请先进行实名认证才可购买。
 OPERATIONDENIED_USERNOTAUTHENTICATEDERROR = 'OperationDenied.UserNotAuthenticatedError'
 
